# FrameworkDrawer
一个绘制简单RTL门级电路的模块

使用方法如下：
```bash
python main.py [-h] --input INPUT --output OUTPUT [--fmt FMT]
```

用例：
```bash
 python .\main.py --input .\model.json --output .\imgs\schema.svg
```

输出的图片效果如下
<div style="background-color: white;">
<img src="./imgs/schema.svg">
</div>
